@@ -1,4 +1,4 @@
-from typing import Type
+from typing import Type, Union
 
 from piplinetest import BaseTestStep, BasePipLineTest
 
@@ -6,3 +6,5 @@ from piplinetest import BaseTestStep, BasePipLineTest
 TestStep = Type[BaseTestStep]
 
 PipLineTest = Type[BasePipLineTest]
+
+Http_Res = Union[dict, str]
